# EnhanceDocs CLI

EnhanceDocs Command Line Interface (CLI)

[![pypi version](https://img.shields.io/pypi/v/enhancedocs.svg)](https://pypi.org/pypi/enhancedocs/)
[![Downloads](https://static.pepy.tech/badge/enhancedocs/week)](https://pypi.org/pypi/enhancedocs/)
[![License: MIT](https://img.shields.io/badge/license-Apache--2.0-yellow)](https://www.apache.org/licenses/LICENSE-2.0)
 [![Twitter](https://img.shields.io/twitter/url/https/twitter.com/enhancedocs.svg?style=social&label=Follow%20%40EnhanceDocs)](https://twitter.com/enhancedocs)
[![](https://dcbadge.vercel.app/api/server/AUDa3KZavw?compact=true&style=flat)](https://discord.gg/AUDa3KZavw)

## Requirements
- [Python 3.11.2](https://www.python.org/downloads/)

## Getting Started

You can install and configure EnhanceDocs using this command:
```bash
pip install -U enhancedocs
```

## Running EnhanceDocs CLI on Github Actions

Set up your GitHub Actions workflow with a specific version of EnhanceDocs CLI.

https://github.com/marketplace/actions/setup-enhancedocs
